@@ -5,13 +5,7 @@
 #' @param log \code{\link[bupaR]{log}}: Object of class \code{\link[bupaR]{log}} or derivatives (\code{\link[bupaR]{grouped_log}}, \code{\link[bupaR]{eventlog}}, \code{\link[bupaR]{activitylog}}, etc.).
 #' @param level \code{\link{character}} (default \code{"log"}): Level of granularity for the analysis: \code{"log"} (default), \code{"trace"}, \code{"case"}, or \code{"activity"}.
 #' For more information, see \code{vignette("metrics", "edeaR")} and 'Details' below.
-#' @param append \code{\link{logical}} (default \code{FALSE}) `r lifecycle::badge("deprecated")`: The arguments \code{append} and \code{append_column}
-#' have been deprecated in favour of \code{\link{augment}}.\cr
-#' Indicating whether to append results to original log. Ignored when level is \code{"log"} or \code{"trace"}.
-#' @param append_column `r lifecycle::badge("deprecated")` The arguments \code{append} and \code{append_column} have been deprecated in favour of \code{\link{augment}}.\cr
-#' Which of the output columns to append to log, if \code{append = TRUE}. Default column depends on chosen level.
 #' @param sort \code{\link{logical}} (default \code{TRUE}): Sort output on count. Only for levels with frequency count output.
-#' @param eventlog `r lifecycle::badge("deprecated")`; please use \code{log} instead.
 #'
 #' @details
 #' Argument \code{level} has the following options:
@@ -33,10 +27,7 @@
 #' @export activity_frequency
 activity_frequency <- function(log,
 							   level = c("log", "trace", "activity", "case"),
-							   append = deprecated(),
-							   append_column = NULL,
-							   sort = TRUE,
-							   eventlog = deprecated()) {
+							   sort = TRUE) {
 	UseMethod("activity_frequency")
 }
 
@@ -45,20 +36,10 @@ activity_frequency <- function(log,
 #' @export
 activity_frequency.eventlog <- function(log,
 										level = c("log", "trace", "activity", "case"),
-										append = deprecated(),
-										append_column = NULL,
-										sort = TRUE,
-										eventlog = deprecated()) {
+										sort = TRUE) {
 
-	log <- lifecycle_warning_eventlog(log, eventlog)
-	append <- lifecycle_warning_append(append)
 	level <- rlang::arg_match(level)
 
-	if(is.null(append_column)) {
-		append_column <- case_when(level == "activity" ~ "absolute",
-								   level == "case" ~ "absolute",
-								   T ~ "NA")
-	}
 
 	FUN <- switch(level,
 				  log = activity_frequency_log,
@@ -73,28 +54,17 @@ activity_frequency.eventlog <- function(log,
 			arrange(-.data[["absolute"]]) -> output
 	}
 
-	return_metric(log, output, level, append, append_column, "activity_frequency")
+	return_metric_v2(log, output, level, "activity_frequency")
 }
 
 #' @describeIn activity_frequency Computes the activity frequency for a \code{\link[bupaR]{grouped_eventlog}}.
 #' @export
 activity_frequency.grouped_eventlog <- function(log,
 												level = c("log", "trace", "activity", "case"),
-												append = deprecated(),
-												append_column = NULL,
-												sort = TRUE,
-												eventlog = deprecated()) {
+												sort = TRUE) {
 
-	log <- lifecycle_warning_eventlog(log, eventlog)
-	append <- lifecycle_warning_append(append)
 	level <- rlang::arg_match(level)
 
-	if(is.null(append_column)) {
-		append_column <- case_when(level == "activity" ~ "absolute",
-								   level == "case" ~ "absolute",
-								   T ~ "NA")
-	}
-
 	FUN <- switch(level,
 				  log = activity_frequency_log,
 				  case = activity_frequency_case,
@@ -102,7 +72,7 @@ activity_frequency.grouped_eventlog <- function(log,
 				  activity = activity_frequency_activity)
 
 	# Doesn't work!
-	bupaR:::apply_grouped_fun(log, FUN, .keep_groups = FALSE, .returns_log = FALSE) -> output
+	apply_grouped_fun(log, FUN, .keep_groups = FALSE, .returns_log = FALSE) -> output
 
 	#if(level != "log") {
 	#	grouped_metric(log, FUN) -> output
@@ -115,37 +85,27 @@ activity_frequency.grouped_eventlog <- function(log,
 			arrange(-.data[["absolute"]]) -> output
 	}
 
-	return_metric(log, output, level, append, append_column, "activity_frequency")
+	return_metric_v2(log, output, level, "activity_frequency")
 }
 
 #' @describeIn activity_frequency Computes the activity frequency for an \code{\link[bupaR]{activitylog}}.
 #' @export
 activity_frequency.activitylog <- function(log,
 										   level = c("log", "trace", "activity", "case"),
-										   append = deprecated(),
-										   append_column = NULL,
-										   sort = TRUE,
-										   eventlog = deprecated()) {
+										   sort = TRUE) {
 
-	log <- lifecycle_warning_eventlog(log, eventlog)
-	append <- lifecycle_warning_append(append)
 	level <- rlang::arg_match(level)
 
-	activity_frequency.eventlog(bupaR::to_eventlog(log), level = level, append = append, append_column = append_column, sort = sort)
+	activity_frequency.eventlog(bupaR::to_eventlog(log), level = level, sort = sort)
 }
 
 #' @describeIn activity_frequency Computes the activity frequency for a \code{\link[bupaR]{grouped_activitylog}}.
 #' @export
 activity_frequency.grouped_activitylog <- function(log,
 												   level = c("log", "trace", "activity", "case"),
-												   append = deprecated(),
-												   append_column = NULL,
-												   sort = TRUE,
-												   eventlog = deprecated()) {
+												   sort = TRUE) {
 
-	log <- lifecycle_warning_eventlog(log, eventlog)
-	append <- lifecycle_warning_append(append)
 	level <- rlang::arg_match(level)
 
-	activity_frequency.grouped_eventlog(bupaR::to_eventlog(log), level = level, append = append, append_column = append_column, sort = sort)
+	activity_frequency.grouped_eventlog(bupaR::to_eventlog(log), level = level, sort = sort)
 }
