@@ -27,8 +27,7 @@ filter_processing_time <- function(log,
 								   interval = NULL,
 								   percentage = NULL,
 								   reverse = FALSE,
-								   units = c("secs", "mins", "hours", "days", "weeks"),
-								   eventlog = deprecated()) {
+								   units = c("secs", "mins", "hours", "days", "weeks")) {
 	UseMethod("filter_processing_time")
 }
 
@@ -38,16 +37,7 @@ filter_processing_time.log <- function(log,
 									   interval = NULL,
 									   percentage = NULL,
 									   reverse = FALSE,
-									   units = c("secs", "mins", "hours", "days", "weeks"),
-									   eventlog = deprecated()) {
-
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "filter_processing_time(eventlog)",
-			with = "filter_processing_time(log)")
-		log <- eventlog
-	}
+									   units = c("secs", "mins", "hours", "days", "weeks")) {
 
 	units <- rlang::arg_match(units)
 
@@ -71,18 +61,9 @@ filter_processing_time.grouped_log <- function(log,
 											   interval = NULL,
 											   percentage = NULL,
 											   reverse = FALSE,
-											   units = c("secs", "mins", "hours", "days", "weeks"),
-											   eventlog = deprecated()) {
+											   units = c("secs", "mins", "hours", "days", "weeks")) {
 
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "filter_processing_time(eventlog)",
-			with = "filter_processing_time(log)")
-		log <- eventlog
-	}
-
-	bupaR:::apply_grouped_fun(log, fun = filter_processing_time.log, interval, percentage, reverse, units, .ignore_groups = FALSE, .keep_groups = TRUE, .returns_log = TRUE)
+	apply_grouped_fun(log, fun = filter_processing_time.log, interval, percentage, reverse, units, .ignore_groups = FALSE, .keep_groups = TRUE, .returns_log = TRUE)
 	#grouped_filter(eventlog, filter_processing_time, interval = interval, percentage = percentage, reverse, units, ...)
 }
 
@@ -110,12 +91,11 @@ check_interval_percentage_args <- function(interval, percentage, call = caller_e
 				  call = call)
 }
 
-#' @keywords internal
-#' @rdname ifilter
+#' @describeIn filter_processing_time Filter interactively
 #' @export ifilter_processing_time
-ifilter_processing_time <- function(eventlog) {
+ifilter_processing_time <- function(log) {
 
-	lifecycle::deprecate_warn("0.9.0", "ifilter_processing_time()")
+	input_cmd <- construct_input_call(sys.calls(), deparse(substitute(log)))
 
 	ui <- miniPage(
 		gadgetTitleBar("Filter Processing Time"),
@@ -123,7 +103,7 @@ ifilter_processing_time <- function(eventlog) {
 			fillCol(
 					fillRow(
 						radioButtons("filter_type", "Filter type:", choices = c("Interval" = "int", "Use percentile cutoff" = "percentile")),
-						radioButtons("units", "Time units: ", choices = c("weeks","days","hours","mins"), selected = "hours"),
+						radioButtons("units", "Time units: ", choices = c("secs", "mins", "hours", "days", "weeks"), selected = "secs"),
 						radioButtons("reverse", "Reverse filter: ", choices = c("Yes","No"), selected = "No")
 					),
 					uiOutput("filter_ui")
@@ -132,11 +112,11 @@ ifilter_processing_time <- function(eventlog) {
 	)
 
 	server <- function(input, output, session){
-
+		my_max <- reactive({round(as.double(max(log %>% processing_time("case", units = input$units) %>% pull(processing_time))),2)})
 		output$filter_ui <- renderUI({
 			if(input$filter_type == "int") {
 				sliderInput("interval_slider", "Process time interval",
-									min = 0, max = max(eventlog %>% processing_time("case", units = input$units) %>% pull(processing_time)), value = c(0,1))
+									min = 0, max = my_max(), value = c(0,my_max()))
 
 			}
 			else if(input$filter_type == "percentile") {
@@ -146,18 +126,20 @@ ifilter_processing_time <- function(eventlog) {
 
 		observeEvent(input$done, {
 			if(input$filter_type == "int")
-				filtered_log <- filter_processing_time(eventlog,
-												 interval = input$interval_slider,
-												 reverse = ifelse(input$reverse == "Yes", T, F),
-												 units = input$units)
+				fun_call <- construct_call(input_cmd, list(interval = list(input$interval_slider),
+														   reverse = list(input$reverse == "Yes", FALSE),
+														   units = list(input$units, "'secs'")))
+
 			else if(input$filter_type == "percentile") {
-				filtered_log <- filter_processing_time(eventlog,
-												 percentage = input$percentile_slider/100,
-												 reverse = ifelse(input$reverse == "Yes", T, F),
-												 units = input$units)
+				fun_call <- construct_call(input_cmd, list(percentage = list(input$percentile_slider/100),
+														   reverse = list(input$reverse == "Yes", FALSE),
+														   units = list(input$units, "'secs'")))
 			}
 
-			stopApp(filtered_log)
+
+			result <- eval(parse_expr(fun_call))
+			rstudioapi::sendToConsole(fun_call)
+			stopApp(result)
 		})
 	}
 	runGadget(ui, server, viewer = dialogViewer("Filter Processing Time", height = 400))
