@@ -5,7 +5,8 @@ filter_processing_time_threshold <- function(log, lower_threshold, upper_thresho
 	upper_threshold <- ifelse(is.na(upper_threshold), Inf, upper_threshold)
 
 	case_selection <- log %>%
-		processing_time("case", units = units) %>%
+		processing_time(level = "case", units = units) %>%
+		mutate("processing_time" = as.numeric(.data[["processing_time"]])) %>%
 		filter(between(processing_time, lower_threshold, upper_threshold)) %>%
 		pull(1)
 
