@@ -9,16 +9,15 @@ plot_resource_involvement <- function(x, ...) {
 	absolute <- NULL
 	relative <- NULL
 
-if(level == "case") {
+	if(level == "case") {
+
+		range <- max(x$absolute) - min(x$absolute)
+
 		x %>%
-			ggplot(aes_string(glue("reorder({mapping$case_id}, relative)"), "relative")) +
-			geom_col(aes(fill = relative)) +
-			scale_fill_continuous_tableau(name = "Relative number of resources involved", palette = "Blue") +
-			coord_flip() +
+			ggplot(aes(absolute)) +
+			geom_histogram(bins = ifelse(range > 20, 20, range+1), fill = col_vector()[1], color = "white") +
 			theme_light() +
-			scale_x_discrete(breaks = NULL) +
-			theme(axis.text.y = element_blank()) +
-			labs(x = "Cases",y = "Relative number of resources") -> p
+			labs(x = "#resources",y = "#cases") -> p
 	}
 	else if(level == "resource-activity") {
 		x %>%
@@ -27,21 +26,21 @@ if(level == "case") {
 			geom_text(aes(label = absolute), fontface = "bold", color = "white") +
 			theme_light() +
 			theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
-			scale_fill_continuous_tableau("Number of cases resource-activity involved in", palette = "Blue") +
+			scale_fill_continuous_bupaR(name = "#cases", palette = "green") +
 			labs(x = "Activities",y = "Resources") -> p
 	}
 	else if(level == "resource") {
 		x %>%
 			ggplot(aes_string(glue("reorder({mapping$resource_id}, absolute)"), "absolute")) +
 			geom_col(aes(fill = absolute)) +
-			scale_fill_continuous_tableau(name = "Number of cases Resource involved in", palette = "Blue") +
+			scale_fill_continuous_bupaR(name = "#cases", palette = "green") +
 			coord_flip() +
 			theme_light() +
-			labs(x = "Resources",y = "Resource frequency") -> p
+			labs(x = "Resources",y = "#cases") -> p
 	}
 
 	if(!is.null(mapping$groups)) {
-		p <- p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+		p <- p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y", space = "free")
 	}
 
 	return(p)
