@@ -10,15 +10,14 @@ plot_resource_specialisation <- function(x, ...) {
 	freq <- NULL
 
 	if(level == "log") {
+		range <- max(attr(x, "raw")$freq) - min(attr(x, "raw")$freq)
+
 		attr(x, "raw") %>%
-			ggplot(aes("", freq)) +
-			geom_boxplot() +
+			ggplot(aes(freq)) +
+			geom_histogram(bins = ifelse(range > 20, 20, range+1), fill = col_vector()[1], color = "white") +
+			scale_x_continuous() +
 			theme_light() +
-			coord_flip() +
-			labs(x = "", y = "Number of activities performed per resource") -> p
-	}
-	else if(level == "case") {
-		stop("No plot available at this level")
+			labs(x = glue("#activities"), y = "#resources") -> p
 	}
 	else if(level == "activity") {
 		x %>%
@@ -26,22 +25,22 @@ plot_resource_specialisation <- function(x, ...) {
 			geom_col(aes(fill = absolute)) +
 			theme_light() +
 			coord_flip() +
-			scale_fill_continuous_tableau("Number of resources performing an activity", palette = "Blue") +
-			labs(x = "Activities",y = "Number of resources") -> p
+			scale_fill_continuous_bupaR(name = "#resources", palette = "green") +
+			labs(x = "Activities",y = "#resources") -> p
 	}
 	else if(level == "resource") {
 		x %>%
 			ggplot(aes_string(glue("reorder({mapping$resource_id}, absolute)"), "absolute")) +
 			geom_col(aes(fill = absolute)) +
-			scale_fill_continuous_tableau(name = "Number of activities executed per resource", palette = "Blue") +
+			scale_fill_continuous_bupaR(name = "#activities", palette = "green") +
 			coord_flip() +
 			theme_light() +
-			labs(x = "Resources",y = "Number of activities") -> p
+			labs(x = "Resources",y = "#activities") -> p
 	}
 
 
 	if(!is.null(mapping$groups)) {
-		p <- p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y")
+		p <- p + facet_grid(as.formula(paste(c(paste(mapping$groups, collapse = "+"), "~." ), collapse = "")), scales = "free_y", space = "free")
 	}
 
 
