@@ -12,33 +12,25 @@
 #'
 #' @export
 #'
-redo_selfloops_referral_matrix <- function(log, eventlog = deprecated()) {
+redo_selfloops_referral_matrix <- function(log) {
 	UseMethod("redo_selfloops_referral_matrix")
 }
 
 #' @describeIn redo_selfloops_referral_matrix Compute matrix for eventlog
 #' @export
 
-redo_selfloops_referral_matrix.eventlog <- function(log, eventlog = deprecated()) {
+redo_selfloops_referral_matrix.eventlog <- function(log) {
 	first_resource <- NULL
 	last_resource <- NULL
 
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "redo_selfloops_referral_matrix(eventlog)",
-			with = "redo_selfloops_referral_matrix(log)")
-		log <- eventlog
-	}
-
-	eventlog %>%
+	log %>%
 		redo_selfloops() %>%
 		group_by(first_resource, last_resource) %>%
 		summarize(absolute = n()) -> output
 
 	class(output) <- c("referral_matrix", class(output))
 	attr(output, "type") <- "selfloop"
-	attr(output, "mapping") <- mapping(eventlog)
+	attr(output, "mapping") <- mapping(log)
 
 	return(output)
 }
@@ -46,15 +38,7 @@ redo_selfloops_referral_matrix.eventlog <- function(log, eventlog = deprecated()
 #' @describeIn redo_selfloops_referral_matrix Compute matrix for activitylog
 #' @export
 
-redo_selfloops_referral_matrix.activitylog <- function(log, eventlog = deprecated()) {
-
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "redo_selfloops_referral_matrix(eventlog)",
-			with = "redo_selfloops_referral_matrix(log)")
-		log <- eventlog
-	}
+redo_selfloops_referral_matrix.activitylog <- function(log) {
 
 	log %>%
 		to_eventlog() %>%
