@@ -4,8 +4,8 @@ resource_frequency_log <- function(log) {
 	freq <- NULL
 
 	log %>%
-		group_by(!!resource_id_(log), !!activity_instance_id_(log)) %>%
-		#summarize() %>%
+		distinct(!!resource_id_(log), !!activity_instance_id_(log)) %>%
+		group_by(!!resource_id_(log)) %>%
 		summarize(freq = n()) -> raw
 
 	output <- raw %>%
