@@ -15,10 +15,7 @@
 #'
 size_of_repetitions <- function(log,
 								type = c("all","repeat","redo"),
-								level = c("log","case","activity","resource","resource-activity"),
-								append = deprecated(),
-								append_column = NULL,
-								eventlog = deprecated()) {
+								level = c("log","case","activity","resource","resource-activity")) {
 	UseMethod("size_of_repetitions")
 }
 #' @describeIn size_of_repetitions Size of repetitions for eventlog
@@ -26,19 +23,8 @@ size_of_repetitions <- function(log,
 
 size_of_repetitions.eventlog <- function(log,
 								type = c("all","repeat","redo"),
-								level = c("log","case","activity","resource","resource-activity"),
-								append = deprecated(),
-								append_column = NULL,
-								eventlog = deprecated()){
+								level = c("log","case","activity","resource","resource-activity")){
 
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "size_of_repetitions(eventlog)",
-			with = "size_of_repetitions(log)")
-		log <- eventlog
-	}
-	append <- lifecycle_warning_append(append)
 
 	if(all((type) == c("all", "repeat","redo")))
 		message("Using default type: all")
@@ -48,14 +34,6 @@ size_of_repetitions.eventlog <- function(log,
 	type <- match.arg(type)
 	level <- match.arg(level)
 
-	if(is.null(append_column)) {
-		append_column <- case_when(level == "case" ~ "median",
-								   level == "resource" ~ "median",
-								   level == "activity"~"median",
-								   level == "resource-activity"~"median",
-								   T ~ "NA")
-	}
-
 	if(type == "all") {
 		FUN <- switch(level,
 					  log = all_repetitions_size_log,
@@ -88,7 +66,7 @@ size_of_repetitions.eventlog <- function(log,
 	output <- FUN(eventlog = log)
 
 
-	output <- return_metric(log, output, level, append, append_column, "size_of_repetitions", 10)
+	output <- return_metric_v2(log, output, level, "size_of_repetitions")
 	attr(output, "type") <- type
 	return(output)
 }
@@ -98,30 +76,12 @@ size_of_repetitions.eventlog <- function(log,
 
 size_of_repetitions.grouped_eventlog <- function(log,
 												 type = c("repeat","redo"),
-												 level = c("log","case","activity","resource","resource-activity"),
-												 append = deprecated(),
-												 append_column = NULL,
-												 eventlog = deprecated()){
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "size_of_repetitions(eventlog)",
-			with = "size_of_repetitions(log)")
-		log <- eventlog
-	}
-	append <- lifecycle_warning_append(append)
+												 level = c("log","case","activity","resource","resource-activity")){
+
 
 	type <- match.arg(type)
 	level <- match.arg(level)
 
-	if(is.null(append_column)) {
-		append_column <- case_when(level == "case" ~ "median",
-								   level == "resource" ~ "median",
-								   level == "activity"~"median",
-								   level == "resource-activity"~"median",
-								   T ~ "NA")
-	}
-
 	if(type == "repeat") {
 		FUN <- switch(level,
 					  log = repeat_repetitions_size_log,
@@ -142,9 +102,9 @@ size_of_repetitions.grouped_eventlog <- function(log,
 
 	}
 
-	output <- bupaR:::apply_grouped_fun(log, FUN, .ignore_groups = FALSE, .keep_groups = FALSE, .returns_log = FALSE)
+	output <- apply_grouped_fun(log, FUN, .ignore_groups = FALSE, .keep_groups = FALSE, .returns_log = FALSE)
 
-	output <- return_metric(log, output, level, append, append_column, "size_of_repetitions", 10)
+	output <- return_metric_v2(log, output, level,"size_of_repetitions")
 	attr(output, "type") <- type
 	return(output)
 }
@@ -154,20 +114,10 @@ size_of_repetitions.grouped_eventlog <- function(log,
 
 size_of_repetitions.activitylog <- function(log,
 												 type = c("repeat","redo"),
-												 level = c("log","case","activity","resource","resource-activity"),
-												 append = deprecated(),
-												 append_column = NULL,
-												 eventlog = deprecated()){
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "size_of_selfloops(eventlog)",
-			with = "size_of_selfloops(log)")
-		log <- eventlog
-	}
-	append <- lifecycle_warning_append(append)
+												 level = c("log","case","activity","resource","resource-activity")){
 
-	log %>% to_eventlog %>% size_of_repetitions(type, level, append, append_column)
+
+	log %>% to_eventlog %>% size_of_repetitions(type, level)
 }
 
 #' @describeIn size_of_repetitions Size of repetitions for grouped activitylog
@@ -175,23 +125,10 @@ size_of_repetitions.activitylog <- function(log,
 
 size_of_repetitions.grouped_activitylog <- function(log,
 												 type = c("repeat","redo"),
-												 level = c("log","case","activity","resource","resource-activity"),
-												 append = deprecated(),
-												 append_column = NULL,
-												 eventlog = deprecated()){
+												 level = c("log","case","activity","resource","resource-activity")){
 
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = "size_of_selfloops(eventlog)",
-			with = "size_of_selfloops(log)")
-		log <- eventlog
-	}
-	append <- lifecycle_warning_append(append)
 
 	size_of_repetitions.grouped_eventlog(bupaR::to_eventlog(log),
 									   type = type,
-									   level = level,
-									   append = append,
-									   append_column = append_column)
+									   level = level)
 }
