@@ -9,7 +9,9 @@ throughput_time_trace <- function(log, units, work_schedule) {
 	# Store time units, because dplyr transformations remove the attributes.
 	time_units <- attr(t, "units")
 
-	merge(t, c, by = case_id(log)) %>%
+	merge(t, c, by = case_id(log)) -> raw
+
+	raw %>%
 		group_by(trace) %>%
 		grouped_summary_statistics("throughput_time", relative_frequency = n()) %>%
 		mutate(relative_frequency = relative_frequency/sum(relative_frequency)) %>%
@@ -17,5 +19,6 @@ throughput_time_trace <- function(log, units, work_schedule) {
 		select(trace, relative_frequency, everything()) -> output
 
 	attr(output, "units") <- time_units
+	attr(output, "raw") <- raw
 	return(output)
 }
