@@ -13,76 +13,76 @@ resource_id_ <- function(eventlog) sym(resource_id(eventlog))
 timestamp_ <- function(eventlog) sym(timestamp(eventlog))
 lifecycle_id_ <- function(eventlog) sym(lifecycle_id(eventlog))
 
+construct_call <- function(input_fun, argument) {
 
-
-
-deprecated_level <- function(level,...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("level_of_analysis",names(l)))) {
-		warning("Argument level_of_analysis is deprecated. Use level instead.")
-		l[stringr::str_detect("level_of_analysis",names(l))][[1]]
+	arguments <- map(argument, format_argument)
+	arguments <- arguments[!is.na(arguments)]
+	if(length(arguments) > 0) {
+		arguments <- paste0(names(arguments), " = ", arguments)
+		arguments <- paste(arguments, collapse = ",")
+		paste0(input_fun,"(",arguments, ")")
 	} else {
-		level
+		paste0(input_fun, "()")
+	}
+
+}
+construct_call_open <- function(input_fun, argument) {
+
+	arguments <- map(argument, format_argument)
+	arguments <- arguments[!is.na(arguments)]
+	if(length(arguments) > 0) {
+		arguments <- paste0(names(arguments), " = ", arguments)
+		arguments <- paste(arguments, collapse = ",")
+		paste0(input_fun,",",arguments, ")")
+	} else {
+		paste0(input_fun, ")")
+	}
+
+}
+
+format_argument <- function(arg_list) {
+	skip <- FALSE
+	if(is.character(arg_list[[1]])) {
+		arg_list[[1]] <- paste0("'", arg_list[[1]], "'")
+	}
+	if(length(arg_list[[1]]) > 1) {
+		arg_list[[1]] <- paste0("c(",paste0(arg_list[[1]], collapse = ","), ")")
+	}
+	if(length(arg_list) > 1) {
+		default <- arg_list[[2]]
+		current <- arg_list[[1]]
+		if(default == current) {
+			skip <- TRUE
+		}
+	}
+
+	if(!skip) {
+		arg_list[[1]]
+	} else {
+		NA
 	}
 }
 
-deprecated_perc <- function(perc,...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("percentile_cut_off",names(l)))) {
-		warning("Argument percentile_cut_off is deprecated. Use percentage instead.")
-		l[stringr::str_detect("percentile_cut_off",names(l))][[1]]
+
+construct_input_call <- function(sc, log) {
+	if(as.character(sc[[1]])[1] == "%>%") {
+		input_cmd <- paste(as.character(sc[[1]])[2], "%>%", str_remove(as.character(sc[[2]][1]), "^i"))
 	} else {
-		perc
+		input_cmd <- paste(as.character(log), "%>%", str_remove(as.character(sc[[1]])[1], "^i"))
 	}
 }
 
-deprecated_lower_thr <- function(int_1,...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("lower_threshold",names(l)))) {
-		warning("Arguments lower_threshold and upper_threshold are deprecated. Use interval instead.")
-		l[stringr::str_detect("lower_threshold",names(l))][[1]]
-	} else {
-		int_1
-	}
-}
 
-deprecated_upper_thr <- function(int_2,...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("upper_threshold",names(l)))) {
-		warning("Arguments lower_threshold and upper_threshold are deprecated. Use interval instead.")
-		l[stringr::str_detect("upper_threshold",names(l))][[1]]
-	} else {
-		int_2
-	}
-}
 
-deprecated_starting_point <- function(s, ...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("start_point",names(l)))) {
-		warning("Arguments start_point and end_point are deprecated. Use interval instead.")
-		l[stringr::str_detect("start_point",names(l))][[1]]
-	} else {
-		s
-	}
-}
 
-deprecated_end_point <- function(e, ...) {
-	l <- list(...)
-	if(length(l) > 0 && any(stringr::str_detect("end_point",names(l)))) {
-		warning("Arguments start_point and end_point are deprecated. Use interval instead.")
-		l[stringr::str_detect("end_point",names(l))][[1]]
-	} else {
-		e
-	}
-}
 
 is_attached <- function(x) {
 	paste0("package:", x) %in% search()
 }
 
 grouped_metric <- function(grouped_eventlog, FUN, ...) {
-	# grouped_metric function should be replaced with bupaR:::apply_grouped_fun
-	bupaR:::apply_grouped_fun(grouped_eventlog, FUN, ...)
+	# grouped_metric function should be replaced with apply_grouped_fun
+	apply_grouped_fun(grouped_eventlog, FUN, ...)
 }
 
 
@@ -149,8 +149,8 @@ return_metric <- function(eventlog, output, level, append, append_column, metric
 
 
 		if(empty_label) {
-		output %>%
-			set_names(c(names(.)[ids], paste0(append_column, "_", level))) -> output
+			output %>%
+				set_names(c(names(.)[ids], paste0(append_column, "_", level))) -> output
 		}
 		else {
 			output %>%
@@ -182,21 +182,37 @@ return_metric <- function(eventlog, output, level, append, append_column, metric
 	}
 }
 
+return_metric_v2 <- function(log,  #original log
+							 output,  # output of metric
+							 level,  #name of level
+							 metric) { #name of metric
+
+	class(output) <- c(str_replace(paste0(level, "_metric"), "-", "_"),metric, class(output)) #replace for resource-activity
+	attr(output, "level") <- level
+	attr(output, "mapping") <- mapping(log)
+	attr(output, "metric_type") <- metric
+	if("grouped_eventlog" %in% class(log)) {
+		attr(output, "groups") <- groups(log)
+	}
+	return(output)
+
+}
+
 
 summary_statistics <- function(vector) {
 
-  vector %>%
-    as_tibble() %>%
-    summarise("min" = suppressWarnings(min(vector, na.rm = T)),
-              "q1" = quantile(vector, probs = 0.25, na.rm = T),
-              "median" = median(vector, na.rm = T),
-              "mean" = mean(vector, na.rm = T),
-              "q3" = quantile(vector, probs = 0.75, na.rm = T),
-              "max" = max(vector, na.rm = T),
-              "st_dev" = suppressWarnings(sd(vector, na.rm = T)),
-              "iqr" = .data[["q3"]] - .data[["q1"]]) -> s
+	vector %>%
+		as_tibble() %>%
+		summarise("min" = suppressWarnings(min(vector, na.rm = T)),
+				  "q1" = quantile(vector, probs = 0.25, na.rm = T),
+				  "median" = median(vector, na.rm = T),
+				  "mean" = mean(vector, na.rm = T),
+				  "q3" = quantile(vector, probs = 0.75, na.rm = T),
+				  "max" = max(vector, na.rm = T),
+				  "st_dev" = suppressWarnings(sd(vector, na.rm = T)),
+				  "iqr" = .data[["q3"]] - .data[["q1"]]) -> s
 
-  return(s)
+	return(s)
 }
 
 grouped_summary_statistics <- function(data.frame, values, na.rm = T, ...) {
@@ -214,52 +230,20 @@ grouped_summary_statistics <- function(data.frame, values, na.rm = T, ...) {
 				  ...)
 }
 
-# Warning: The `eventlog` argument of `func()` is deprecated as of edeaR 0.9.0.
-# Please use the `log` argument instead.
-# WARNING: Works only on exported functions!
-lifecycle_warning_eventlog <- function (log, eventlog = deprecated()) {
-
-	cl <- sys.call(-1L)
-	func <- get(as.character(cl[[1L]]), mode = "function", envir = sys.frame(-2L))
-	func_name <- match.call(definition = func, call = cl)[[1L]]
-
-	if(lifecycle::is_present(eventlog)) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = paste0(func_name, "(eventlog)"),
-			with = paste0(func_name, "(log)"))
-		return(eventlog)
-	}
-
-	return(log)
-}
-
-lifecycle_warning_append <- function (append = deprecated(), append_column = deprecated()) {
-
-	cl <- sys.call(-1L)
-	func <- get(as.character(cl[[1L]]), mode = "function", envir = sys.frame(-2L))
-	func_name <- match.call(definition = func, call = cl)[[1L]]
-
-	if (lifecycle::is_present(append) ) {
-		lifecycle::deprecate_warn(
-			when = "0.9.0",
-			what = paste0(func_name, "(append)"),
-			with = "augment()"
-		)
-	} else {
-		append <- rlang::missing_arg()
-	}
-
-	return(rlang::maybe_missing(append))
-}
 
 check_activities <- function(specified_activities, found_activities, arg = "activities", call = caller_env(), emit_warning = TRUE) {
 	wrong <- specified_activities[!(specified_activities %in% found_activities)]
 	if (length(wrong) > 0 && emit_warning) {
 		cli_warn(c("{.val {length(wrong)}} specified activit{?y/ies} in {.arg {arg}} not found in {.arg log}.",
-				   "!" = "Activit{?y/ies} not found and ignored: {.val {wrong}}."),
+				   "!" = "Activit{?y/ies} not found: {.val {wrong}}."),
 				 call = call)
 	}
 	specified_activities[!(specified_activities %in% wrong)]
 }
-
+col_vector <- function() {
+	c("#339999", "#8ADA8A","#FF8749","#6C6DAF","#008FAD", "#A44165",
+	  "#005E5E", "#5DBE7C","#A93800", "#AC76C6", "#70D0CF" , "#935592",
+	  "#324B4B","#1F884B","#956F5D", "#7E88BC", "#00C9CE","#4A5787",
+	  "#428E78", "#007851",  "#7F4C35", "#3681B7", 	  "#009EC0",
+	  "#95B1B0",   "#849237",   "#00282A")
+}
